==> chromium_89.0.4389.114.orig.tar.xz: chromium-89.0.4389.114/chrome/browser/notifications/notification_handler.cc <==
// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/notifications/notification_handler.h"

#include "base/callback.h"

NotificationHandler::~NotificationHandler() = default;

void NotificationHandler::OnShow(Profile* profile,
                                 const std::string& notification_id) {}

void NotificationHandler::OnClose(Profile* profile,
                                  const GURL& origin,
                                  const std::string& notification_id,
                                  bool by_user,
                                  base::OnceClosure completed_closure) {
  std::move(completed_closure).Run();
}

void NotificationHandler::OnClick(Profile* profile,
                                  const GURL& origin,
                                  const std::string& notification_id,
                                  const base::Optional<int>& action_index,
                                  const base::Optional<base::string16>& reply,
                                  base::OnceClosure completed_closure) {
  std::move(completed_closure).Run();
}

void NotificationHandler::DisableNotifications(Profile* profile,
                                               const GURL& origin) {
  NOTREACHED();
}

void NotificationHandler::OpenSettings(Profile* profile, const GURL& origin) {
  // Notification types that display a settings button must override this method
  // to handle user interaction with it.
  NOTREACHED();
}

==> chromium-93.0.4544.0.tar.xz: chromium-93.0.4544.0/chrome/browser/notifications/notification_handler.cc <==
// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/notifications/notification_handler.h"

#include "base/callback.h"

NotificationHandler::~NotificationHandler() = default;

void NotificationHandler::OnShow(Profile* profile,
                                 const std::string& notification_id) {}

void NotificationHandler::OnClose(Profile* profile,
                                  const GURL& origin,
                                  const std::string& notification_id,
                                  bool by_user,
                                  base::OnceClosure completed_closure) {
  std::move(completed_closure).Run();
}

void NotificationHandler::OnClick(Profile* profile,
                                  const GURL& origin,
                                  const std::string& notification_id,
                                  const absl::optional<int>& action_index,
                                  const absl::optional<std::u16string>& reply,
                                  base::OnceClosure completed_closure) {
  std::move(completed_closure).Run();
}

void NotificationHandler::DisableNotifications(Profile* profile,
                                               const GURL& origin) {
  NOTREACHED();
}

void NotificationHandler::OpenSettings(Profile* profile, const GURL& origin) {
  // Notification types that display a settings button must override this method
  // to handle user interaction with it.
  NOTREACHED();
}
